@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
+#-*- coding: utf-8 -*-
 
+import doctest
 import unittest
-from zope.testing import doctest
 
 
 def test_suite():
